@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -37,7 +37,16 @@ ChatConfigurationHolder * ChatConfigurationHolder::instance()
 	return Instance;
 }
 
-ChatConfigurationHolder::ChatConfigurationHolder()
+ChatConfigurationHolder::ChatConfigurationHolder() :
+		AutoSend{},
+		NiceDateFormat{},
+		ChatTextCustomColors{},
+		ForceCustomChatFont{},
+		ChatBgFilled{},
+		UseTransparency{},
+		ContactStateChats{},
+		ContactStateWindowTitle{},
+		ContactStateWindowTitlePosition{}
 {
 }
 
@@ -58,8 +67,6 @@ void ChatConfigurationHolder::configurationUpdated()
 	ForceCustomChatFont = config_file.readBoolEntry("Look", "ForceCustomChatFont");
 	ChatFont = config_file.readFontEntry("Look", "ChatFont");
 
-	EmoticonsStyle = config_file.readNumEntry("Chat", "EmoticonsStyle");
-
 	ChatContents = config_file.readEntry("Look", "ChatContents");
 	ConferenceContents = config_file.readEntry("Look", "ConferenceContents");
 	ConferencePrefix = config_file.readEntry("Look", "ConferencePrefix");
@@ -83,3 +90,5 @@ void ChatConfigurationHolder::configurationUpdated()
 
 	emit chatConfigurationUpdated();
 }
+
+#include "moc_chat-configuration-holder.cpp"
