@@ -1,8 +1,9 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,9 +25,9 @@
 
 #include <QtCore/QString>
 #include <QtGui/QPixmap>
+#include <QtGui/QStyleOptionViewItemV4>
 
 class QModelIndex;
-class QStyleOptionViewItemV4;
 
 class TalkableDelegateConfiguration;
 
@@ -40,7 +41,7 @@ class AvatarPainter
 	QPixmap Avatar;
 
 	bool greyOut();
-
+	QPixmap cropped();
 	QString cacheKey();
 	QPixmap getOrCreateCacheItem();
 	void paintFromCache(QPainter *painter);
