@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
@@ -27,6 +27,8 @@
 #include "buddies/buddy.h"
 
 class BuddyContactsTableItem;
+class ConfigurationValueStateNotifier;
+class SimpleConfigurationValueStateNotifier;
 
 class BuddyContactsTableModel : public QAbstractTableModel
 {
@@ -34,6 +36,7 @@ class BuddyContactsTableModel : public QAbstractTableModel
 
 	Buddy ModelBuddy;
 	QList<BuddyContactsTableItem *> Contacts;
+	SimpleConfigurationValueStateNotifier *StateNotifier;
 
 	int CurrentMaxPriority;
 
@@ -49,6 +52,9 @@ class BuddyContactsTableModel : public QAbstractTableModel
 
 	void sendAuthorization(const Contact &contact);
 
+	bool isValid() const;
+	void updateStateNotifier();
+
 private slots:
 	void itemUpdated(BuddyContactsTableItem *item);
 
@@ -56,7 +62,8 @@ public:
 	explicit BuddyContactsTableModel(Buddy buddy, QObject *parent = 0);
 	virtual ~BuddyContactsTableModel();
 
-	bool isValid();
+	const ConfigurationValueStateNotifier * valueStateNotifier() const;
+
 	void save();
 
 	BuddyContactsTableItem * item(int row);
@@ -75,9 +82,6 @@ public:
 
 	virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
 
-signals:
-	void validChanged();
-
 };
 
 #endif // BUDDY_CONTACTS_TABLE_MODEL_H
