@@ -1,7 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@
 #define DEFAULT_PROXY_INDEX 1
 
 ProxyComboBox::ProxyComboBox(QWidget *parent) :
-		ActionsComboBox(parent), InActivatedSlot(false), DefaultProxyAction(0)
+		ActionsComboBox(parent), DefaultProxyAction(0)
 {
 	addBeforeAction(new QAction(tr(" - No proxy - "), this));
 
@@ -90,3 +90,5 @@ void ProxyComboBox::editProxy()
 {
 	ProxyEditWindow::show();
 }
+
+#include "moc_proxy-combo-box.cpp"
