@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,8 +27,7 @@
 #include <QtGui/QPushButton>
 
 #include "gui/windows/message-dialog.h"
-#include "gui/windows/syntax-editor-window.h"
-#include "misc/misc.h"
+#include "misc/kadu-paths.h"
 #include "misc/syntax-list.h"
 
 #include "syntax-editor.h"
@@ -41,14 +40,7 @@ SyntaxEditor::SyntaxEditor(QWidget *parent) :
 	syntaxListCombo = new QComboBox(this);
 	connect(syntaxListCombo, SIGNAL(activated(const QString &)), this, SLOT(syntaxChangedSlot(const QString &)));
 
-	QPushButton *editButton = new QPushButton(tr("Edit"), this);
-	deleteButton = new QPushButton(tr("Delete"), this);
-	connect(editButton, SIGNAL(clicked()), this, SLOT(editClicked()));
-	connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteClicked()));
-
 	layout->addWidget(syntaxListCombo, 100);
-	layout->addWidget(editButton);
-	layout->addWidget(deleteButton);
 }
 
 SyntaxEditor::~SyntaxEditor()
@@ -80,27 +72,6 @@ void SyntaxEditor::setSyntaxHint(const QString &syntaxHint)
 	this->syntaxHint = syntaxHint;
 }
 
-void SyntaxEditor::editClicked()
-{
-	SyntaxEditorWindow *editor = new SyntaxEditorWindow(syntaxList, syntaxListCombo->currentText(), category, syntaxHint);
-	connect(editor, SIGNAL(updated(const QString &)), this, SLOT(setCurrentSyntax(const QString &)));
-
-	emit onSyntaxEditorWindowCreated(editor);
-	editor->refreshPreview();
-	editor->show();
-}
-
-void SyntaxEditor::deleteClicked()
-{
-	if (!syntaxList)
-		return;
-
-	if (syntaxList->deleteSyntax(currentSyntax()))
-		setCurrentSyntax(*(syntaxList->keys().constBegin()));
-	else
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Unable to remove syntax: %1").arg(currentSyntax()));
-}
-
 void SyntaxEditor::syntaxChangedSlot(const QString &newSyntax)
 {
 	if (!syntaxList)
@@ -128,7 +99,6 @@ void SyntaxEditor::syntaxChangedSlot(const QString &newSyntax)
 	content = stream.readAll();
 	file.close();
 
-	deleteButton->setEnabled(!info.global);
 	emit syntaxChanged(content);
 }
 
@@ -147,3 +117,5 @@ void SyntaxEditor::syntaxListUpdated()
 	syntaxListCombo->clear();
 	syntaxListCombo->addItems(syntaxList->keys());
 }
+
+#include "moc_syntax-editor.cpp"
