@@ -2,9 +2,9 @@
  * %kadu copyright begin%
  * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2011, 2014 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009, 2010 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
@@ -29,6 +29,7 @@
 
 #include "accounts/account.h"
 #include "buddies/buddy.h"
+#include "exports.h"
 #include "os/generic/desktop-aware-object.h"
 
 class QCheckBox;
@@ -41,7 +42,7 @@ class AccountsComboBox;
 class GroupsComboBox;
 class SelectTalkableComboBox;
 
-class AddBuddyWindow : public QDialog, DesktopAwareObject
+class KADUAPI AddBuddyWindow : public QDialog, DesktopAwareObject
 {
 	Q_OBJECT
 
