@@ -3,8 +3,8 @@
  * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,36 +21,32 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtCore/QChar>
+#include <QtDeclarative/QDeclarativeContext>
+#include <QtDeclarative/QDeclarativeView>
+#include <QtGui/QApplication>
 #include <QtGui/QDesktopWidget>
 #include <QtGui/QDialogButtonBox>
+#include <QtGui/QGraphicsObject>
 #include <QtGui/QKeyEvent>
 #include <QtGui/QLabel>
 #include <QtGui/QPushButton>
+#include <QtGui/QStyle>
 #include <QtGui/QVBoxLayout>
 
-#include "accounts/account-manager.h"
-#include "accounts/account.h"
 #include "buddies/buddy-manager.h"
 #include "buddies/buddy-set.h"
 #include "buddies/model/buddy-list-model.h"
 #include "chat/chat-manager.h"
 #include "chat/type/chat-type-contact.h"
-#include "chat/type/chat-type-contact-set.h"
 #include "configuration/xml-configuration-file.h"
-#include "contacts/contact-manager.h"
-#include "contacts/contact-set.h"
 #include "contacts/contact.h"
 #include "core/core.h"
-#include "gui/widgets/chat-widget-manager.h"
-#include "gui/widgets/chat-widget.h"
+#include "gui/widgets/chat-widget/chat-widget-manager.h"
 #include "gui/widgets/filtered-tree-view.h"
 #include "gui/widgets/line-edit-with-clear-button.h"
-#include "gui/widgets/talkable-tree-view.h"
-#include "misc/misc.h"
+#include "misc/kadu-paths.h"
 #include "model/model-chain.h"
-#include "os/generic/url-opener.h"
-#include "protocols/services/roster/roster-entry.h"
+#include "model/roles.h"
 #include "talkable/model/talkable-proxy-model.h"
 
 #include "activate.h"
@@ -72,7 +68,7 @@ OpenChatWith * OpenChatWith::instance()
 }
 
 OpenChatWith::OpenChatWith() :
-	QWidget(0, Qt::Window), DesktopAwareObject(this), IsTyping(false)
+		QWidget(0, Qt::Window), DesktopAwareObject(this)
 {
 	kdebugf();
 
@@ -81,10 +77,10 @@ OpenChatWith::OpenChatWith() :
 	setWindowTitle(tr("Open chat with..."));
 	setAttribute(Qt::WA_DeleteOnClose);
 
-	int width = QDesktopWidget().availableGeometry().width()*0.25;
-	int height = QDesktopWidget().availableGeometry().height()*0.3;
-	QRect rect(QDesktopWidget().availableGeometry().center().x()-width/2, QDesktopWidget().availableGeometry().center().y()-height/2, width, height);
-	setWindowGeometry(this, rect);
+	QRect availableGeometry = qApp->desktop()->availableGeometry(this);
+	int width = static_cast<int>(0.25f * availableGeometry.width());
+	int height = static_cast<int>(0.6f * availableGeometry.height());
+	setGeometry(availableGeometry.center().x() - width / 2, availableGeometry.center().y() - height / 2, width, height);
 
 	MainLayout = new QVBoxLayout(this);
 
@@ -95,22 +91,29 @@ OpenChatWith::OpenChatWith() :
 	idLayout->addWidget(new QLabel(tr("User name:"), idWidget));
 
 	ContactID = new LineEditWithClearButton(this);
-	ContactID->installEventFilter(this);
 	connect(ContactID, SIGNAL(textChanged(const QString &)), this, SLOT(inputChanged(const QString &)));
 	idLayout->addWidget(ContactID);
 
-	BuddiesWidget = new TalkableTreeView(this);
-	connect(BuddiesWidget, SIGNAL(talkableActivated(Talkable)), this, SLOT(openChat()));
-
 	MainLayout->addWidget(idWidget);
-	MainLayout->addWidget(BuddiesWidget);
 
-	ModelChain *chain = new ModelChain(this);
-	ListModel = new BuddyListModel(chain);
-	chain->setBaseModel(ListModel);
-	chain->addProxyModel(new TalkableProxyModel(chain));
+	BuddiesView = new QDeclarativeView();
 
-	BuddiesWidget->setChain(chain);
+	Chain = new ModelChain(this);
+	ListModel = new BuddyListModel(Chain);
+	Chain->setBaseModel(ListModel);
+	Chain->addProxyModel(new TalkableProxyModel(Chain));
+
+	QDeclarativeContext *declarativeContext = BuddiesView->rootContext();
+	declarativeContext->setContextProperty("buddies", Chain->lastModel());
+
+	BuddiesView->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+	BuddiesView->setResizeMode(QDeclarativeView::SizeRootObjectToView);
+	BuddiesView->setSource(QUrl("file:///" + KaduPaths::instance()->dataPath() + "qml/openChatWith.qml"));
+
+	if (BuddiesView->rootObject())
+		connect(BuddiesView->rootObject(), SIGNAL(itemActivated(int)), this, SLOT(itemActivated(int)));
+
+	MainLayout->addWidget(BuddiesView);
 
 	QDialogButtonBox *buttons = new QDialogButtonBox(Qt::Horizontal, this);
 
@@ -127,12 +130,12 @@ OpenChatWith::OpenChatWith() :
 
 	OpenChatRunner = new OpenChatWithContactListRunner();
 	OpenChatWithRunnerManager::instance()->registerRunner(OpenChatRunner);
-	kdebugf2();
+
+	inputChanged(QString());
 }
 
 OpenChatWith::~OpenChatWith()
 {
-	//saveWindowGeometry(this, "General", "OpenChatWith");
 	OpenChatWithRunnerManager::instance()->unregisterRunner(OpenChatRunner);
 	Instance = 0;
 
@@ -140,29 +143,6 @@ OpenChatWith::~OpenChatWith()
 	OpenChatRunner = 0;
 }
 
-bool OpenChatWith::eventFilter(QObject *obj, QEvent *e)
-{
-	if (obj == ContactID && e->type() == QEvent::KeyPress)
-	{
-		if (static_cast<QKeyEvent *>(e)->modifiers() == Qt::NoModifier)
-		{
-			int key = static_cast<QKeyEvent *>(e)->key();
-			if (key == Qt::Key_Down ||
-					key == Qt::Key_Up ||
-					key == Qt::Key_PageDown ||
-					key == Qt::Key_PageUp ||
-					(key == Qt::Key_Left && ContactID->cursorPosition() == 0) ||
-					(key == Qt::Key_Right && ContactID->cursorPosition() == ContactID->text().length()))
-			{
-				qApp->sendEvent(BuddiesWidget, e);
-				return true;
-			}
-		}
-	}
-
-	return false;
-}
-
 void OpenChatWith::keyPressEvent(QKeyEvent *e)
 {
 	kdebugf();
@@ -180,11 +160,20 @@ void OpenChatWith::keyPressEvent(QKeyEvent *e)
 			close();
 			return;
 			break;
+		case Qt::Key_Down:
+		case Qt::Key_Up:
+		case Qt::Key_PageDown:
+		case Qt::Key_PageUp:
+			BuddiesView->setFocus();
+			QCoreApplication::sendEvent(BuddiesView, e);
+			focusQml();
+			e->accept();
+			return;
 	}
 
 	if (FilteredTreeView::shouldEventGoToFilter(e))
 	{
-		ContactID->setText(e->text());
+		ContactID->setText(ContactID->text() + e->text());
 		ContactID->setFocus(Qt::OtherFocusReason);
 		e->accept();
 		return;
@@ -195,87 +184,52 @@ void OpenChatWith::keyPressEvent(QKeyEvent *e)
 	kdebugf2();
 }
 
+void OpenChatWith::focusQml()
+{
+	auto rootObject = dynamic_cast<QObject *>(BuddiesView->rootObject());
+	if (!rootObject)
+		return;
+
+	auto mainWidget = rootObject->findChild<QObject *>("mainWidget");
+	if (!mainWidget)
+		return;
+
+	mainWidget->setProperty("focus", true);
+}
+
 void OpenChatWith::inputChanged(const QString &text)
 {
 	kdebugf();
 
 	BuddyList matchingContacts = text.isEmpty()
-			? BuddyList()
+			? BuddyManager::instance()->items().toList()
 			: OpenChatWithRunnerManager::instance()->matchingContacts(text);
 
 	ListModel->setBuddyList(matchingContacts);
-
-	if (!text.isEmpty())
-	{
-		if (!IsTyping || BuddiesWidget->selectionModel()->selectedIndexes().isEmpty())
-		{
-			BuddiesWidget->setCurrentIndex(BuddiesWidget->model()->index(0, 0));
-			BuddiesWidget->selectionModel()->select(BuddiesWidget->model()->index(0, 0), QItemSelectionModel::SelectCurrent);
-		}
-		IsTyping = true;
-	}
-	else
-		IsTyping = false;
-
-	kdebugf2();
 }
 
-void OpenChatWith::openChat()
+void OpenChatWith::itemActivated(int index)
 {
-	ContactSet contacts = BuddiesWidget->actionContext()->contacts();
-
-	if (contacts.isEmpty())
-	{
-		close();
+	QModelIndex modelIndex = Chain->lastModel()->index(index, 0);
+	if (!modelIndex.isValid())
 		return;
-	}
 
-	// In case a contact was added to the manager after BuddiesWidget was created,
-	// ensure that we don't add actually duplicate contacts to the manager.
-	ContactSet knownContacts;
-	for (ContactSet::iterator it = contacts.begin(), end = contacts.end(); it != end; )
-	{
-		Contact knownContact = ContactManager::instance()->byId(it->contactAccount(), it->id(), ActionReturnNull);
-		if (knownContact)
-		{
-			it = contacts.erase(it);
-			knownContacts.insert(knownContact);
-		}
-		else
-		{
-			it->rosterEntry()->setState(RosterEntrySynchronized);
-			ContactManager::instance()->addItem(*it);
-			++it;
-		}
-	}
-
-	contacts.unite(knownContacts);
-
-	BuddySet buddies = contacts.toBuddySet();
-
-	const Chat &chat = 1 == contacts.size()
-			? ChatTypeContact::findChat(*contacts.constBegin(), ActionCreateAndAdd)
-	 		: ChatTypeContactSet::findChat(contacts, ActionCreateAndAdd);
-	if (chat)
-	{
-		ChatWidget * const chatWidget = ChatWidgetManager::instance()->byChat(chat, true);
-		if (chatWidget)
-			chatWidget->activate();
-
-		close();
+	Contact contact = modelIndex.data(ContactRole).value<Contact>();
+	if (!contact)
 		return;
-	}
 
-	const Buddy &buddy = *buddies.constBegin();
-	if (buddy.mobile().isEmpty() && !buddy.email().isEmpty())
-		UrlOpener::openEmail(buddy.email().toUtf8());
+	Chat chat = ChatTypeContact::findChat(contact, ActionCreateAndAdd);
+	if (!chat)
+		return;
 
-	close();
+	Core::instance()->chatWidgetManager()->openChat(chat, OpenChatActivation::Activate);
+	deleteLater();
 }
 
 void OpenChatWith::inputAccepted()
 {
-	openChat();
+	if (BuddiesView->rootObject())
+		itemActivated(BuddiesView->rootObject()->property("currentIndex").toInt());
 }
 
 void OpenChatWith::show()
@@ -285,3 +239,5 @@ void OpenChatWith::show()
 	else
 		_activateWindow(this);
 }
+
+#include "moc_open-chat-with.cpp"
