@@ -1,6 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -43,8 +45,8 @@ protected:
 	virtual void store();
 
 public:
-	static NetworkProxyShared * loadStubFromStorage(const QSharedPointer<StoragePoint> &networkProxyStoragePoint);
-	static NetworkProxyShared * loadFromStorage(const QSharedPointer<StoragePoint> &networkProxyStoragePoint);
+	static NetworkProxyShared * loadStubFromStorage(const std::shared_ptr<StoragePoint> &networkProxyStoragePoint);
+	static NetworkProxyShared * loadFromStorage(const std::shared_ptr<StoragePoint> &networkProxyStoragePoint);
 
 	explicit NetworkProxyShared(const QUuid &uuid = QUuid());
 	virtual ~NetworkProxyShared();
