@@ -2,13 +2,13 @@
  * %kadu copyright begin%
  * Copyright 2010, 2010, 2011, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
  * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
- * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@
 #include "protocols/protocol-state-machine.h"
 #include "services/chat-service.h"
 #include "services/chat-state-service.h"
-#include "services/roster-service.h"
+#include "services/roster/roster-service.h"
 #include "status/status-adapter.h"
 #include "status/status-type-manager.h"
 #include "status/status.h"
@@ -299,12 +299,29 @@ void Protocol::setChatService(ChatService * const chatService)
 	CurrentChatService = chatService;
 }
 
+ChatService * Protocol::chatService()
+{
+	return CurrentChatService.data();
+}
+
 void Protocol::setChatStateService(ChatStateService * const chatStateService)
 {
 	CurrentChatStateService = chatStateService;
 }
 
+ChatStateService * Protocol::chatStateService()
+{
+	return CurrentChatStateService.data();
+}
+
 void Protocol::setRosterService(RosterService * const rosterService)
 {
 	CurrentRosterService = rosterService;
 }
+
+RosterService * Protocol::rosterService() const
+{
+	return CurrentRosterService.data();
+}
+
+#include "moc_protocol.cpp"
