@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
 <context>
     <name>@default</name>
     <message>
@@ -33,7 +31,7 @@
     </message>
     <message>
         <source>Message was cenzored</source>
-        <translation type="unfinished">Il messaggio è stato censurato</translation>
+        <translation>Il messaggio è stato censurato</translation>
     </message>
 </context>
 <context>
@@ -48,7 +46,7 @@
     </message>
     <message>
         <source>Cenzor</source>
-        <translation type="unfinished">Censura</translation>
+        <translation>Censura</translation>
     </message>
 </context>
 <context>
@@ -66,4 +64,4 @@
         <translation>Cancella</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
