@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="pl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
 <context>
     <name>@default</name>
     <message>
@@ -66,4 +64,4 @@
         <translation>Usuń</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
