@@ -2,7 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2008, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2007, 2008 Dawid Stawiarski (neeo@kadu.net)
  * %kadu copyright end%
  *
@@ -20,27 +21,35 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CHAT_NOTIFIER_H
-#define CHAT_NOTIFIER_H
+#pragma once
+
+#include <QtCore/QPointer>
 
 #include "notify/notifier.h"
 
 class ChatWidget;
+class ChatWidgetRepository;
+class FormattedStringFactory;
 
 class ChatNotifier : public Notifier
 {
 	Q_OBJECT
 
-	void sendNotificationToChatWidget(Notification *notification, ChatWidget *chatWidget);
-
 public:
 	explicit ChatNotifier(QObject *parent = 0);
 	virtual ~ChatNotifier();
 
+	void setChatWidgetRepository(ChatWidgetRepository *chatWidgetRepository);
+	void setFormattedStringFactory(FormattedStringFactory *formattedStringFactory);
+
 	virtual NotifierConfigurationWidget * createConfigurationWidget(QWidget *parent = 0);
 
 	virtual void notify(Notification *notification);
 
-};
+private:
+	QPointer<ChatWidgetRepository> m_chatWidgetRepository;
+	QPointer<FormattedStringFactory> m_formattedStringFactory;
 
-#endif // CHAT_NOTIFIER_H
+	void sendNotificationToChatWidget(Notification *notification, ChatWidget *chatWidget);
+
+};
