@@ -1,12 +1,6 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
 <context>
     <name>@default</name>
-    <message>
-        <source>Status</source>
-        <translation>Stato</translation>
-    </message>
     <message>
         <source>FileDesc</source>
         <translation>FileDesc</translation>
@@ -19,10 +13,6 @@
         <source>Enter here a file, which will contain descriptions to refresh by module.</source>
         <translation>Inserisci qui il un file che dovrà contenere le descrizioni aggiornate dal modulo</translation>
     </message>
-    <message>
-        <source>Force status to be &apos;with description&apos;</source>
-        <translation>Forza lo stato a diventare &quot;Con Descrizione&quot;</translation>
-    </message>
     <message>
         <source>If you choose status without description, module will set it automatically to similar but with description</source>
         <translation>Se scegli uno stato senza descrizione, il modulo sarà settato automaticamente ad uno simile ma con la descrizione</translation>
@@ -33,7 +23,19 @@
     </message>
     <message>
         <source>Allows you to set some custom description manualy, until file contents does not change</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Behavior</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Always add description to status</source>
+        <translation type="unfinished"/>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
