@@ -149,10 +149,6 @@
         <source>64px</source>
         <translation>64px</translation>
     </message>
-    <message>
-        <source>Show buttons only when necessary</source>
-        <translation>Afficher les boutons seulement au moment nécessaire</translation>
-    </message>
     <message>
         <source>New Chat/Message</source>
         <translation>Nouvelle conversation / Nouveau message</translation>
@@ -161,10 +157,6 @@
         <source>Advanced</source>
         <translation>Avancé</translation>
     </message>
-    <message>
-        <source>Advanced...</source>
-        <translation>Avancé...</translation>
-    </message>
     <message>
         <source> px</source>
         <translation> px</translation>
@@ -225,6 +217,14 @@
         <source>&lt;b&gt;Here&lt;/b&gt; you can see the preview</source>
         <translation>Vous pouvez voir l&apos;aperçu &lt;b&gt;ici&lt;/b&gt;</translation>
     </message>
+    <message>
+        <source>Show buttons only if notification requires user&apos;s action</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Hints size and position...</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>HintManager</name>
