@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
 <context>
     <name>@default</name>
     <message>
@@ -39,44 +37,67 @@
         <source>Save status only with description</source>
         <translation>Salva solo stati con la descrizione</translation>
     </message>
-    <message>
-        <source>Quotation</source>
-        <translation>Quotazione</translation>
-    </message>
-    <message>
-        <source>Quote message in chat window</source>
-        <translation>Messaggio quotato in finestra di chat</translation>
-    </message>
-    <message>
-        <source>.</source>
-        <translation>.</translation>
-    </message>
     <message>
         <source>Shortcuts</source>
         <translation>Scorciatoie</translation>
     </message>
-    <message>
-        <source>General</source>
-        <translation>Generale</translation>
-    </message>
     <message>
         <source>View history</source>
         <translation>Visualizza cronologia</translation>
     </message>
     <message>
-        <source>Do not quote messages older than</source>
-        <translation type="unfinished"></translation>
+        <source>Save chats in history</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Kadu</source>
-        <translation type="unfinished">Kadu</translation>
+        <source>History in chat window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Show messages from history since</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Choose time period in which messages can be quoted in chat window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>yesterday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>last week</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>last month</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Limit number of messages from history</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Behavior</source>
+        <translation>Conservazione</translation>
+    </message>
+    <message>
+        <source>Chat window</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>BuddyHistoryDeleteHandler</name>
+    <message>
+        <source>Chat history</source>
+        <translation>Cronologia Chat</translation>
     </message>
 </context>
 <context>
     <name>ChatHistoryTab</name>
     <message>
         <source>&amp;Clear Chat History</source>
-        <translation type="unfinished">&amp;Pulisci Cronologia Chat</translation>
+        <translation>&amp;Pulisci Cronologia Chat</translation>
     </message>
 </context>
 <context>
@@ -85,61 +106,73 @@
         <source>Clear History</source>
         <translation>Pulisci cronologia</translation>
     </message>
+</context>
+<context>
+    <name>HistoryBuddyConfigurationWidget</name>
     <message>
-        <source>%1 day(s) %2 hour(s)</source>
-        <translation>%1 giorno(i) %2 ora(e)</translation>
+        <source>History</source>
+        <translation>Cronologia</translation>
+    </message>
+    <message>
+        <source>Store history</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>HistoryBuddyDataWindowAddons</name>
+    <name>HistoryChatConfigurationWidget</name>
     <message>
-        <source>Store history</source>
-        <translation type="unfinished"></translation>
+        <source>History</source>
+        <translation>Cronologia</translation>
     </message>
-</context>
-<context>
-    <name>HistoryChatDataWindowAddons</name>
     <message>
         <source>Store history</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>HistoryMessagesTab</name>
     <message>
         <source>&amp;Remove entries</source>
-        <translation type="unfinished">&amp;Rimuovi ingressi</translation>
+        <translation>&amp;Rimuovi ingressi</translation>
     </message>
     <message>
         <source>Filter</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Kadu</source>
-        <translation type="unfinished">Kadu</translation>
+        <translation>Kadu</translation>
     </message>
     <message>
         <source>Do you really want to delete history?</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete history</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annulla</translation>
     </message>
 </context>
 <context>
     <name>HistoryQueryResultsModel</name>
     <message>
         <source>Chat</source>
-        <translation type="unfinished">Chat</translation>
+        <translation>Chat</translation>
     </message>
     <message>
         <source>Length</source>
-        <translation type="unfinished">Lunghezza</translation>
+        <translation>Lunghezza</translation>
     </message>
     <message>
         <source>Date</source>
-        <translation type="unfinished">Data</translation>
+        <translation>Data</translation>
     </message>
     <message>
         <source>Title</source>
-        <translation type="unfinished">Titolo</translation>
+        <translation>Titolo</translation>
     </message>
 </context>
 <context>
@@ -162,108 +195,101 @@
     </message>
     <message>
         <source>Chats</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Statuses</source>
-        <translation type="unfinished">Stati</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>SMS</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>QApplication</name>
-    <message>
-        <source>Chat history</source>
-        <translation>Cronologia Chat</translation>
+        <translation>SMS</translation>
     </message>
 </context>
 <context>
     <name>SearchTab</name>
     <message>
         <source>Search for:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Chats</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source> - All chats - </source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Statuses</source>
-        <translation type="unfinished">Stati</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source> - All buddies - </source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Smses</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source> - All recipients - </source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>By date</source>
-        <translation type="unfinished"></translation>
+        <translation>Per data</translation>
     </message>
     <message>
         <source>to</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Search</source>
-        <translation type="unfinished">Cerca</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Found</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Chat</source>
-        <translation type="unfinished">Chat</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Buddy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Recipient</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>ShowHistoryActionDescription</name>
     <message>
         <source>View Chat History</source>
-        <translation type="unfinished">Visualizza cronologia chat</translation>
+        <translation>Visualizza cronologia chat</translation>
     </message>
     <message>
         <source>Show last %1 messages</source>
-        <translation type="unfinished">Visualizza l&apos;ultimo %1 messaggi</translation>
+        <translation>Visualizza l&apos;ultimo %1 messaggi</translation>
     </message>
     <message>
         <source>Show messages since yesterday</source>
-        <translation type="unfinished">Visualizza messaggi da ieri</translation>
+        <translation>Visualizza messaggi da ieri</translation>
     </message>
     <message>
         <source>Show messages from last 7 days</source>
-        <translation type="unfinished">Visualizza messaggi degli ultimi 7 giorni</translation>
+        <translation>Visualizza messaggi degli ultimi 7 giorni</translation>
     </message>
     <message>
         <source>Show messages from last 30 days</source>
-        <translation type="unfinished">Visualizza messaggi degli ultimi 30 giorni</translation>
+        <translation>Visualizza messaggi degli ultimi 30 giorni</translation>
     </message>
     <message>
         <source>Show whole history</source>
-        <translation type="unfinished">Visualizza tutta la cronologia</translation>
+        <translation>Visualizza tutta la cronologia</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
