@@ -3,8 +3,8 @@
  * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -33,7 +33,7 @@
 #include "core/core.h"
 #include "gui/windows/kadu-window.h"
 #include "gui/windows/message-dialog.h"
-#include "misc/misc.h"
+#include "misc/kadu-paths.h"
 #include "plugins/history/history.h"
 #include "debug.h"
 
@@ -45,7 +45,7 @@
 #include "history-importer.h"
 
 HistoryImporter::HistoryImporter(const Account &account, const QString &path, QObject *parent) :
-		QObject(parent), DestinationAccount(account), SourceDirectory(path), Thread(0), ProgressWindow(0)
+		QObject(parent), DestinationAccount(account), SourceDirectory(path), Thread(0), HistoryImport(0), ProgressWindow(0)
 {
 	kdebugf();
 }
@@ -95,7 +95,8 @@ void HistoryImporter::run()
 		return;
 	}
 
-	HistoryImport = new HistoryImportThread(DestinationAccount, SourceDirectory, uinsLists, totalEntries);
+	HistoryImport = new HistoryImportThread(DestinationAccount, SourceDirectory, uinsLists);
+	HistoryImport->setFormattedStringFactory(Core::instance()->formattedStringFactory());
 	HistoryImport->prepareChats();
 
 	Thread = new QThread();
@@ -139,3 +140,5 @@ void HistoryImporter::threadFinished()
 
 	deleteLater();
 }
+
+#include "moc_history-importer.cpp"
