@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
 <context>
     <name>HistoryImportWindow</name>
     <message>
@@ -23,4 +21,4 @@
         <translation>Importa cronologia...</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
