@@ -1,27 +1,25 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
 <context>
     <name>@default</name>
     <message>
         <source>Chat</source>
         <translation>Chat</translation>
     </message>
-    <message>
-        <source>Imagelink</source>
-        <translation>Imagelink</translation>
-    </message>
     <message>
         <source>Show YouTube movies in chat window</source>
         <translation>Mostra video YouTube nella finestra di chat</translation>
     </message>
-    <message>
-        <source>Autoplay movies</source>
-        <translation>Autoriproduci video</translation>
-    </message>
     <message>
         <source>Show images in chat window</source>
         <translation>Mostra immagini nella finestra di chat</translation>
     </message>
+    <message>
+        <source>General</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Messages</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
