@@ -1,8 +1,9 @@
 /*
  * %kadu copyright begin%
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2011 Marcin Dawidziuk (cinekdawidziuk@gmail.com)
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -72,7 +73,7 @@ private slots:
 	void notificationClosed(Notification *notification);
 
 	void chatUpdated(const Chat &chat);
-	void chatWidgetCreated(ChatWidget *chatWidget);
+	void chatWidgetAdded(ChatWidget *chatWidget);
 
 	void silentModeToggled(bool silentMode);
 
@@ -92,8 +93,4 @@ public:
 
 };
 
-// for MOC
-#include "notify/notification.h"
-#include <libindicate-qt/qindicateindicator.h>
-
 #endif // INDICATOR_DOCKING_H
