@@ -101,7 +101,7 @@ JT_Session::JT_Session(Task *parent) : Task(parent)
 {
 }
 
-void JT_Session::onGo() 
+void JT_Session::onGo()
 {
 	QDomElement iq = createIQ(doc(), "set", "", id());
 	QDomElement session = doc()->createElement("session");
@@ -110,7 +110,7 @@ void JT_Session::onGo()
 	send(iq);
 }
 
-bool JT_Session::take(const QDomElement& x) 
+bool JT_Session::take(const QDomElement& x)
 {
 	if(!iqVerify(x, "", id()))
 		return false;
@@ -425,8 +425,8 @@ void JT_Roster::onGo()
 		QDomElement query = doc()->createElement("query");
 		query.setAttribute("xmlns", "jabber:iq:roster");
 		iq.appendChild(query);
-		for(QList<QDomElement>::ConstIterator it = d->itemList.begin(); it != d->itemList.end(); ++it)
-			query.appendChild(*it);
+		foreach (const QDomElement& it, d->itemList)
+			query.appendChild(it);
 		send(iq);
 	}
 }
@@ -443,8 +443,8 @@ QString JT_Roster::toString() const
 
 	QDomElement i = doc()->createElement("request");
 	i.setAttribute("type", "JT_Roster");
-	for(QList<QDomElement>::ConstIterator it = d->itemList.begin(); it != d->itemList.end(); ++it)
-		i.appendChild(*it);
+	foreach (const QDomElement& it, d->itemList)
+		i.appendChild(it);
 	return lineEncode(Stream::xmlToString(i));
 	return "";
 }
@@ -589,7 +589,7 @@ void JT_Presence::pres(const Status &s)
 				c.setAttribute("hash",s.capsHashAlgorithm());
 			c.setAttribute("node",s.capsNode());
 			c.setAttribute("ver",s.capsVersion());
-			if (!s.capsExt().isEmpty()) 
+			if (!s.capsExt().isEmpty())
 				c.setAttribute("ext",s.capsExt());
 			tag.appendChild(c);
 		}
@@ -608,6 +608,8 @@ void JT_Presence::pres(const Status &s)
 					h.setAttribute("maxstanzas",s.mucHistoryMaxStanzas());
 				if (s.mucHistorySeconds() >= 0)
 					h.setAttribute("seconds",s.mucHistorySeconds());
+				if (!s.mucHistorySince().isNull())
+					h.setAttribute("since", s.mucHistorySince().toUTC().addSecs(1).toString(Qt::ISODate));
 				m.appendChild(h);
 			}
 			tag.appendChild(m);
@@ -696,9 +698,8 @@ bool JT_PushPresence::take(const QDomElement &e)
 		}
 		else if(type == "subscribe" || type == "subscribed" || type == "unsubscribe" || type == "unsubscribed") {
 			QString nick;
-			bool found;
-			QDomElement tag = findSubTag(e, "nick", &found);
-			if (found && tag.attribute("xmlns") == "http://jabber.org/protocol/nick") {
+			QDomElement tag = e.firstChildElement("nick");
+			if (!tag.isNull() && tag.attribute("xmlns") == "http://jabber.org/protocol/nick") {
 				nick = tagContent(tag);
 			}
 			subscription(j, type, nick);
@@ -707,16 +708,15 @@ bool JT_PushPresence::take(const QDomElement &e)
 	}
 
 	QDomElement tag;
-	bool found;
 
-	tag = findSubTag(e, "status", &found);
-	if(found)
+	tag = e.firstChildElement("status");
+	if(!tag.isNull())
 		p.setStatus(tagContent(tag));
-	tag = findSubTag(e, "show", &found);
-	if(found)
+	tag = e.firstChildElement("show");
+	if(!tag.isNull())
 		p.setShow(tagContent(tag));
-	tag = findSubTag(e, "priority", &found);
-	if(found)
+	tag = e.firstChildElement("priority");
+	if(!tag.isNull())
 		p.setPriority(tagContent(tag).toInt());
 
 	QDateTime stamp;
@@ -738,14 +738,13 @@ bool JT_PushPresence::take(const QDomElement &e)
 		}
 		else if(i.tagName() == "x" && i.attribute("xmlns") == "gabber:x:music:info") {
 			QDomElement t;
-			bool found;
 			QString title, state;
 
-			t = findSubTag(i, "title", &found);
-			if(found)
+			t = i.firstChildElement("title");
+			if(!t.isNull())
 				title = tagContent(t);
-			t = findSubTag(i, "state", &found);
-			if(found)
+			t = i.firstChildElement("state");
+			if(!t.isNull())
 				state = tagContent(t);
 
 			if(!title.isEmpty() && state == "playing")
@@ -764,9 +763,8 @@ bool JT_PushPresence::take(const QDomElement &e)
   		}
 		else if(i.tagName() == "x" && i.attribute("xmlns") == "vcard-temp:x:update") {
 			QDomElement t;
-			bool found;
-			t = findSubTag(i, "photo", &found);
-			if (found)
+			t = i.firstChildElement("photo");
+			if (!t.isNull())
 				p.setPhotoHash(tagContent(t));
 			else
 				p.setPhotoHash("");
@@ -777,9 +775,9 @@ bool JT_PushPresence::take(const QDomElement &e)
 				if(muc_e.isNull())
 					continue;
 
-				if (muc_e.tagName() == "item") 
+				if (muc_e.tagName() == "item")
 					p.setMUCItem(MUCItem(muc_e));
-				else if (muc_e.tagName() == "status") 
+				else if (muc_e.tagName() == "status")
 					p.addMUCStatus(muc_e.attribute("code").toInt());
 				else if (muc_e.tagName() == "destroy")
 					p.setMUCDestroy(MUCDestroy(muc_e));
@@ -849,12 +847,13 @@ static QDomElement oldStyleNS(const QDomElement &e)
 	return i;
 }
 
-JT_Message::JT_Message(Task *parent, const Message &msg)
+JT_Message::JT_Message(Task *parent, const Message &msg, bool want_notify)
 :Task(parent)
 {
 	m = msg;
 	if (m.id().isEmpty())
 		m.setId(id());
+	w_notify = want_notify;
 }
 
 JT_Message::~JT_Message()
@@ -865,7 +864,7 @@ void JT_Message::onGo()
 {
 	Stanza s = m.toStanza(&(client()->stream()));
 	QDomElement e = oldStyleNS(s.element());
-	send(e);
+	send(e, w_notify);
 	setSuccess();
 }
 
@@ -953,26 +952,25 @@ bool JT_GetServices::take(const QDomElement &x)
 				a.setJid(Jid(i.attribute("jid")));
 
 				QDomElement tag;
-				bool found;
 
-				tag = findSubTag(i, "name", &found);
-				if(found)
+				tag = i.firstChildElement("name");
+				if(!tag.isNull())
 					a.setName(tagContent(tag));
 
 				// determine which namespaces does item support
 				QStringList ns;
 
-				tag = findSubTag(i, "register", &found);
-				if(found)
+				tag = i.firstChildElement("register");
+				if(!tag.isNull())
 					ns << "jabber:iq:register";
-				tag = findSubTag(i, "search", &found);
-				if(found)
+				tag = i.firstChildElement("search");
+				if(!tag.isNull())
 					ns << "jabber:iq:search";
-				tag = findSubTag(i, "groupchat", &found);
-				if(found)
+				tag = i.firstChildElement("groupchat");
+				if(!tag.isNull())
 					ns << "jabber:iq:conference";
-				tag = findSubTag(i, "transport", &found);
-				if(found)
+				tag = i.firstChildElement("transport");
+				if(!tag.isNull())
 					ns << "jabber:iq:gateway";
 
 				a.setFeatures(ns);
@@ -1244,19 +1242,18 @@ bool JT_Search::take(const QDomElement &x)
 					SearchResult r(Jid(i.attribute("jid")));
 
 					QDomElement tag;
-					bool found;
 
-					tag = findSubTag(i, "nick", &found);
-					if(found)
+					tag = i.firstChildElement("nick");
+					if(!tag.isNull())
 						r.setNick(tagContent(tag));
-					tag = findSubTag(i, "first", &found);
-					if(found)
+					tag = i.firstChildElement("first");
+					if(!tag.isNull())
 						r.setFirst(tagContent(tag));
-					tag = findSubTag(i, "last", &found);
-					if(found)
+					tag = i.firstChildElement("last");
+					if(!tag.isNull())
 						r.setLast(tagContent(tag));
-					tag = findSubTag(i, "email", &found);
-					if(found)
+					tag = i.firstChildElement("email");
+					if(!tag.isNull())
 						r.setEmail(tagContent(tag));
 
 					d->resultList += r;
@@ -1305,17 +1302,16 @@ bool JT_ClientVersion::take(const QDomElement &x)
 		return false;
 
 	if(x.attribute("type") == "result") {
-		bool found;
 		QDomElement q = queryTag(x);
 		QDomElement tag;
-		tag = findSubTag(q, "name", &found);
-		if(found)
+		tag = q.firstChildElement("name");
+		if(!tag.isNull())
 			v_name = tagContent(tag);
-		tag = findSubTag(q, "version", &found);
-		if(found)
+		tag = q.firstChildElement("version");
+		if(!tag.isNull())
 			v_ver = tagContent(tag);
-		tag = findSubTag(q, "os", &found);
-		if(found)
+		tag = q.firstChildElement("os");
+		if(!tag.isNull())
 			v_os = tagContent(tag);
 
 		setSuccess();
@@ -1444,11 +1440,10 @@ bool JT_ServInfo::take(const QDomElement &e)
 		// Find out the node
 		bool invalid_node = false;
 		QString node;
-		bool found;
-		QDomElement q = findSubTag(e, "query", &found);
-		if(found) // NOTE: Should always be true, since a NS was found above
+		QDomElement q = e.firstChildElement("query");
+		if(!q.isNull()) // NOTE: Should always be true, since a NS was found above
 			node = q.attribute("node");
-		
+
 		QDomElement iq = createIQ(doc(), "result", e.attribute("from"), e.attribute("id"));
 		QDomElement query = doc()->createElement("query");
 		query.setAttribute("xmlns", "http://jabber.org/protocol/disco#info");
@@ -1475,42 +1470,48 @@ bool JT_ServInfo::take(const QDomElement &e)
 
 		QDomElement feature;
 		if (node.isEmpty() || node == client()->capsNode() + "#" + client()->capsVersion()) {
-			// Standard features
-//			feature = doc()->createElement("feature");
-//			feature.setAttribute("var", "http://jabber.org/protocol/bytestreams");
-//			query.appendChild(feature);
+			if (client()->fileTransferManager()) {
+				// Standard features
+				feature = doc()->createElement("feature");
+				feature.setAttribute("var", "http://jabber.org/protocol/bytestreams");
+				query.appendChild(feature);
+
+				feature = doc()->createElement("feature");
+				feature.setAttribute("var", "http://jabber.org/protocol/ibb");
+				query.appendChild(feature);
+
+				feature = doc()->createElement("feature");
+				feature.setAttribute("var", "http://jabber.org/protocol/si");
+				query.appendChild(feature);
+
+				feature = doc()->createElement("feature");
+				feature.setAttribute("var", "http://jabber.org/protocol/si/profile/file-transfer");
+				query.appendChild(feature);
+			}
 
 			feature = doc()->createElement("feature");
-			feature.setAttribute("var", "http://jabber.org/protocol/ibb");
+			feature.setAttribute("var", "http://jabber.org/protocol/disco#info");
 			query.appendChild(feature);
 
-//			feature = doc()->createElement("feature");
-//			feature.setAttribute("var", "http://jabber.org/protocol/si");
-//			query.appendChild(feature);
-
-//			feature = doc()->createElement("feature");
-//			feature.setAttribute("var", "http://jabber.org/protocol/si/profile/file-transfer");
-//			query.appendChild(feature);
-			
-//			feature = doc()->createElement("feature");
-//			feature.setAttribute("var", "http://jabber.org/protocol/disco#info");
-//			query.appendChild(feature);
-
 			feature = doc()->createElement("feature");
 			feature.setAttribute("var", "urn:xmpp:bob");
 			query.appendChild(feature);
 
+			feature = doc()->createElement("feature");
+			feature.setAttribute("var", "urn:xmpp:ping");
+			query.appendChild(feature);
+
 			// Client-specific features
 			QStringList clientFeatures = client()->features().list();
-			for (QStringList::ConstIterator i = clientFeatures.begin(); i != clientFeatures.end(); ++i) {
+			foreach (const QString & i, clientFeatures) {
 				feature = doc()->createElement("feature");
-				feature.setAttribute("var", *i);
+				feature.setAttribute("var", i);
 				query.appendChild(feature);
 			}
 
 			if (node.isEmpty()) {
 				// Extended features
-				QStringList exts = client()->extensions();
+				const QStringList exts = client()->extensions();
 				for (QStringList::ConstIterator i = exts.begin(); i != exts.end(); ++i) {
 					const QStringList& l = client()->extension(*i).list();
 					for ( QStringList::ConstIterator j = l.begin(); j != l.end(); ++j ) {
@@ -1538,19 +1539,19 @@ bool JT_ServInfo::take(const QDomElement &e)
 		else {
 			invalid_node = true;
 		}
-		
+
 		if (!invalid_node) {
 			send(iq);
 		}
 		else {
 			// Create error reply
 			QDomElement error_reply = createIQ(doc(), "result", e.attribute("from"), e.attribute("id"));
-			
+
 			// Copy children
 			for (QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling()) {
 				error_reply.appendChild(n.cloneNode());
 			}
-			
+
 			// Add error
 			QDomElement error = doc()->createElement("error");
 			error.setAttribute("type","cancel");
@@ -1631,29 +1632,27 @@ bool JT_Gateway::take(const QDomElement &x)
 	if(x.attribute("type") == "result") {
 		if(type == 0) {
 			QDomElement query = queryTag(x);
-			bool found;
 			QDomElement tag;
-			tag = findSubTag(query, "desc", &found);
-			if (found) {
+			tag = query.firstChildElement("desc");
+			if (!tag.isNull()) {
 				v_desc = tagContent(tag);
 			}
-			tag = findSubTag(query, "prompt", &found);
-			if (found) {
+			tag = query.firstChildElement("prompt");
+			if (!tag.isNull()) {
 				v_prompt = tagContent(tag);
 			}
 		}
 		else {
 			QDomElement query = queryTag(x);
-			bool found;
 			QDomElement tag;
-			tag = findSubTag(query, "jid", &found);
-			if (found) {
+			tag = query.firstChildElement("jid");
+			if (!tag.isNull()) {
 				v_translatedJid = tagContent(tag);
 			}
 			// we used to read 'prompt' in the past
 			// and some gateways still send it
-			tag = findSubTag(query, "prompt", &found);
-			if (found) {
+			tag = query.firstChildElement("prompt");
+			if (!tag.isNull()) {
 				v_prompt = tagContent(tag);
 			}
 		}
@@ -2067,3 +2066,31 @@ BoBData JT_BitsOfBinary::data()
 {
 	return d->data;
 }
+
+//----------------------------------------------------------------------------
+// JT_PongServer
+//----------------------------------------------------------------------------
+/**
+ * \class JT_PongServer
+ * \brief Answers XMPP Pings
+ */
+
+JT_PongServer::JT_PongServer(Task *parent)
+:Task(parent)
+{
+
+}
+
+bool JT_PongServer::take(const QDomElement &e)
+{
+	if (e.tagName() != "iq" || e.attribute("type") != "get")
+		return false;
+
+	QDomElement ping = e.firstChildElement("ping");
+	if (!e.isNull() && ping.attribute("xmlns") == "urn:xmpp:ping") {
+		QDomElement iq = createIQ(doc(), "result", e.attribute("from"), e.attribute("id"));
+		send(iq);
+		return true;
+	}
+	return false;
+}
