@@ -3,7 +3,8 @@
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
@@ -29,13 +30,13 @@ LastSeenPlugin::~LastSeenPlugin()
 {
 }
 
-int LastSeenPlugin::init(bool firstLoad)
+bool LastSeenPlugin::init(bool firstLoad)
 {
 	Q_UNUSED(firstLoad)
 
 	InfosInstance = new Infos(this);
 
-	return 0;
+	return true;
 }
 
 void LastSeenPlugin::done()
@@ -45,3 +46,5 @@ void LastSeenPlugin::done()
 }
 
 Q_EXPORT_PLUGIN2(last_seen, LastSeenPlugin)
+
+#include "moc_last-seen-plugin.cpp"
