@@ -1,8 +1,9 @@
 /*
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010 badboy (badboy@gen2.org)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -32,12 +33,11 @@ MPDMediaPlayer::~MPDMediaPlayer()
 {
 }
 
-int MPDMediaPlayer::init(bool firstLoad)
+bool MPDMediaPlayer::init(bool firstLoad)
 {
 	Q_UNUSED(firstLoad)
 
-	bool res = MediaPlayer::instance()->registerMediaPlayer(this, this);
-	return res ? 0 : 1;
+	return MediaPlayer::instance()->registerMediaPlayer(this, this);
 }
 
 void MPDMediaPlayer::done()
@@ -415,3 +415,5 @@ void MPDMediaPlayer::decrVolume()
 }
 
 Q_EXPORT_PLUGIN2(mpd_mediaplayer, MPDMediaPlayer)
+
+#include "moc_mpd-mediaplayer.cpp"
