@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="pl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
 <context>
     <name>ImportProfileWindow</name>
     <message>
@@ -119,4 +117,4 @@ Plik kadu.conf.xml nie został odnaleziony</translation>
         <translation>Importuj zewnętrzny profil...</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
