@@ -2,7 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2009 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,19 +20,15 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _SMS_EXPORTS_H
+#ifndef SMS_EXPORTS_H
+#define SMS_EXPORTS_H
 
-#include "exports.h"
+#include <QtCore/QtGlobal>
 
-#ifdef KADULIB
-#define SMSAPI KADU_EXPORT
+#ifdef sms_EXPORTS
+#define SMSAPI Q_DECL_EXPORT
 #else
-#ifdef SMS_BUILD
-#define SMSAPI KADU_EXPORT
-#else
-#define SMSAPI KADU_IMPORT
+#define SMSAPI Q_DECL_IMPORT
 #endif
-#endif // KADULIB
 
-#define _SMS_EXPORTS_H
-#endif
+#endif // SMS_EXPORTS_H
