@@ -13,14 +13,6 @@
         <source>General</source>
         <translation>Général</translation>
     </message>
-    <message>
-        <source>Use sounds</source>
-        <translation>Utilise les bruitages</translation>
-    </message>
-    <message>
-        <source>Theme</source>
-        <translation>Thème</translation>
-    </message>
     <message>
         <source>Sound theme</source>
         <translation>Thème sonore</translation>
@@ -37,6 +29,10 @@
         <source>Play a sound</source>
         <translation>Jouer un son</translation>
     </message>
+    <message>
+        <source>Enable sound notifications</source>
+        <translation>Activer les notifications sonores</translation>
+    </message>
 </context>
 <context>
     <name>SoundActions</name>
