@@ -13,14 +13,6 @@
         <source>General</source>
         <translation>Ogólne</translation>
     </message>
-    <message>
-        <source>Use sounds</source>
-        <translation>Używaj dźwięków</translation>
-    </message>
-    <message>
-        <source>Theme</source>
-        <translation>Zestaw</translation>
-    </message>
     <message>
         <source>Sound theme</source>
         <translation>Zestaw dźwięków</translation>
@@ -37,6 +29,10 @@
         <source>Play a sound</source>
         <translation>Odtwórz dźwięk</translation>
     </message>
+    <message>
+        <source>Enable sound notifications</source>
+        <translation>Włącz powiadomienia dźwiękowe</translation>
+    </message>
 </context>
 <context>
     <name>SoundActions</name>
