@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="ru">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
 <context>
     <name>@default</name>
     <message>
@@ -15,6 +13,10 @@
         <source>Enable word fix</source>
         <translation>позволяют коррекции слова</translation>
     </message>
+    <message>
+        <source>Spelling</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>WordFix</name>
@@ -47,4 +49,4 @@
         <translation>Заменить</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
